@@ -55,7 +55,15 @@ class UserIdentity(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(UserIdentity.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                identity_pool_options: typing.Optional[typing.Union[aws_cdk.aws_cognito_identitypool_alpha.IdentityPoolProps, typing.Dict[str, typing.Any]]] = None,
+                user_pool: typing.Optional[aws_cdk.aws_cognito.UserPool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = UserIdentityProps(
@@ -114,7 +122,13 @@ class UserIdentityProps:
         if isinstance(identity_pool_options, dict):
             identity_pool_options = aws_cdk.aws_cognito_identitypool_alpha.IdentityPoolProps(**identity_pool_options)
         if __debug__:
-            type_hints = typing.get_type_hints(UserIdentityProps.__init__)
+            def stub(
+                *,
+                identity_pool_options: typing.Optional[typing.Union[aws_cdk.aws_cognito_identitypool_alpha.IdentityPoolProps, typing.Dict[str, typing.Any]]] = None,
+                user_pool: typing.Optional[aws_cdk.aws_cognito.UserPool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument identity_pool_options", value=identity_pool_options, expected_type=type_hints["identity_pool_options"])
             check_type(argname="argument user_pool", value=user_pool, expected_type=type_hints["user_pool"])
         self._values: typing.Dict[str, typing.Any] = {}
